##  Discovery Capabilities
Netskope integration offers the following capabilities:
Available Capabilities | Description | Netskope Resource
---|---|---
SaaS Discovery (Standard) | SaaS discovery automatically identifies your organization's SaaS applications. | Discovered apps


**Note**
Currently, the Netskope integration does not provide usage indication.
You get the following information about the discovered SaaS:
Field | Description
---|---
External Category |
Managed App | Indicates whether a company has a corporate instance and manages it.
App Tags | Tags assigned to the application.
Last seen at | Last time the discovered SaaS was seen in the source system
Item status in source |  Status of the discovered SaaS in the source system. It can be the following:
  * Active: The application has been seen in Netskope in the last week.
  * Inactive: The application has not been seen in the last week.




